@@ -437,14 +437,14 @@ def _pdb_chain(cls: Molecule):
         if not cls.get_residue_link(cls.residues[i-1], res, "residue"):
             length = i - start
             if length > 1:
-                chains[alphabet] = {j + 1: start + j + 1 for j in range(length + 1)}
-                chain_ids[start: start + length + 1] = alphabet * (length + 1)
+                chains[alphabet] = {j + 1: start + j + 1 for j in range(length)}
+                chain_ids[start: start + length] = alphabet * length
                 alphabet = chr(ord(alphabet) + 1)
             start = i
-    length = i - start
+    length = i - start + 1
     if length > 1:
-        chains[alphabet] = {j + 1: start + j for j in range(length + 1)}
-        chain_ids[start: start + length + 1] = alphabet * (length + 1)
+        chains[alphabet] = {j + 1: start + j + 1 for j in range(length)}
+        chain_ids[start: start + length] = alphabet * length
     return chains, chain_ids
 
 
@@ -481,7 +481,7 @@ def _pdb_sequence(cls: Molecule, chains: Xdict):
         pdb_index.sort()
         names = []
         for i in pdb_index:
-            mol_index = index_map[i]
+            mol_index = index_map[i] - 1
             name = cls.residues[mol_index].name
             name = GlobalSetting.PDBResidueNameMap["save"][name] \
                 if name in GlobalSetting.PDBResidueNameMap["save"] else name
@@ -528,7 +528,7 @@ def _pdb_residue_link(cls: Molecule, chain_ids: Xdict, chains: Xdict):
                 a.name == res_a.type.connect_atoms["ssbond"] and \
                 b.name == res_b.type.connect_atoms["ssbond"]:
             ssbonds.append("CYX {0:1s} {1:4d}    CYX {2:1s} {3:4d}\n".format(
-                chain_a, chains_inverse[chain_a][res_index_a], chain_b, chains_inverse[chain_b][res_index_b]))
+                chain_a, chains_inverse[chain_a][res_index_a] + 1, chain_b, chains_inverse[chain_b][res_index_b] + 1))
         else:
             save_names = GlobalSetting.PDBResidueNameMap["save"]
             name_a = save_names[res_a.name] if res_a.name in save_names else res_a.name
@@ -563,6 +563,7 @@ def save_pdb(cls, filename=None):
         cls.atom_index = {cls.atoms[i]: i for i in range(len(cls.atoms))}
         cls.residue_index = {cls.residues[i]: i for i in range(len(cls.residues))}
         cls.link_to_next = [False for res in cls.residues]
+        cls.link_to_next.append(False)
         for link in cls.residue_links:
             if cls.residue_index[link.atom1.residue] - cls.residue_index[link.atom2.residue] == 1:
                 cls.link_to_next[cls.residue_index[link.atom2.residue]] = True
@@ -570,7 +571,6 @@ def save_pdb(cls, filename=None):
                 cls.link_to_next[cls.residue_index[link.atom1.residue]] = True
 
         chains, chain_ids = _pdb_chain(cls)
-
         towrite = "REMARK   Generated By Xponge (Molecule)\n"
         towrite += _pdb_sequence(cls, chains)
         connects, temp_towrite = _pdb_residue_link(cls, chain_ids, chains)
@@ -588,7 +588,8 @@ def save_pdb(cls, filename=None):
                 atom.x, atom.y, atom.z, " ", " ")
             if atom == atom.residue.atoms[-1] and not cls.link_to_next[cls.residue_index[atom.residue]]:
                 towrite += "TER\n"
-                if cls.residue_index[atom.residue] - real_chain_residue0 != 1:
+                temp = cls.residue_index[atom.residue]
+                if temp - real_chain_residue0 != 1 or cls.link_to_next[temp + 1]:
                     chain_residue0 = cls.residue_index[atom.residue]
                     real_chain_residue0 = chain_residue0
                 else:
